@@ -772,7 +772,7 @@ void Annotation::setDisposeDataFunction(DisposeDataFunction func)
 void Annotation::setNativeData(std::shared_ptr<void> data)
 {
     Q_D(Annotation);
-    d->m_nativeData = data;
+    d->m_nativeData = std::move(data);
 }
 
 const void *Annotation::nativeData() const
@@ -2376,7 +2376,7 @@ public:
     QString m_text;
     QString m_leftText;
     QString m_imagePath;
-    QString m_fieldPartialName;
+    QString m_fieldPartialName = QUuid::createUuid().toString();
     int m_page;
     std::function<SigningResult(const Okular::NewSignatureData &, const QString &)> m_signFunction;
 };
