@@ -446,7 +446,7 @@ static Okular::SigningResult popperToOkular(Poppler::SignatureAnnotation::Signin
     case Poppler::SignatureAnnotation::GenericSigningError:
         return Okular::GenericSigningError;
     }
-    Q_UNREACHABLE_RETURN(Okular::GenericSigningError);
+    return Okular::GenericSigningError;
 }
 
 void resizeImage(const SignatureImageHelper *helper, int page, const Okular::NormalizedRect &bRect, Poppler::Document *pdfdoc)
